summaryrefslogtreecommitdiff
path: root/includes/pear/Text/Wiki/Parse/Default/Html.php
diff options
context:
space:
mode:
Diffstat (limited to 'includes/pear/Text/Wiki/Parse/Default/Html.php')
-rwxr-xr-x[-rw-r--r--]includes/pear/Text/Wiki/Parse/Default/Html.php10
1 files changed, 5 insertions, 5 deletions
diff --git a/includes/pear/Text/Wiki/Parse/Default/Html.php b/includes/pear/Text/Wiki/Parse/Default/Html.php
index 38e7389..27b8f89 100644..100755
--- a/includes/pear/Text/Wiki/Parse/Default/Html.php
+++ b/includes/pear/Text/Wiki/Parse/Default/Html.php
@@ -12,7 +12,7 @@
*
* @license LGPL
*
-* @version $Id: Html.php 180591 2005-02-23 17:38:29Z pmjones $
+* @version $Id$
*
*/
@@ -20,7 +20,7 @@
*
* Parses for blocks of HTML code.
*
* This class implements a Text_Wiki_Parse to find source text marked as
* HTML to be redndred as-is. The block start is marked by <html> on its
* own line, and the block end is marked by </html> on its own line.
*
@@ -32,7 +32,7 @@
*
*/
-class Text_Wiki_Parse_Html extends Text_Wiki_Parse {
+class Text_Wiki_Parse_Default_Html extends Text_Wiki_Parse {
/**
@@ -68,8 +68,8 @@ class Text_Wiki_Parse_Html extends Text_Wiki_Parse {
function process(&$matches)
{
- $options = array('text' => $matches[1]);
+ $options = array("text" => $matches[1]);
return $this->wiki->addToken($this->rule, $options) . $matches[2];
}
}
-?> \ No newline at end of file
+?>
@@ -20,7 +20,7 @@
* Parses for blocks of HTML code.
*
-* This class implements a Text_Wiki_Parse to find source text marked as
+* This class implements a Text_Wiki_Parse_Default to find source text marked as
* HTML to be redndred as-is. The block start is marked by <html> on its
* own line, and the block end is marked by </html> on its own line.